import{d as o,b as t,J as n,aw as r,e as a}from"./lucide-8Ndi-dzR.js";const u=o({__name:"PartyGuestLayout",setup(s){return(c,_)=>{const e=r("router-view");return a(),t("div",null,[n(e)])}}});export{u as default};
